[folded-merged] bitmap_parselist-move-non-parser-logic-to-helpers-fix.patch removed from -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled
     Subject: bitmap_parselist-move-non-parser-logic-to-helpers-fix
has been removed from the -mm tree.  Its filename was
     bitmap_parselist-move-non-parser-logic-to-helpers-fix.patch

This patch was dropped because it was folded into bitmap_parselist-move-non-parser-logic-to-helpers.patch

------------------------------------------------------
From: Andrew Morton <akpm@xxxxxxxxxxxxxxxxxxxx>
Subject: bitmap_parselist-move-non-parser-logic-to-helpers-fix

rename grlen to group_len, per Yury

Cc: Yury Norov <ynorov@xxxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxxxxxxxxxxxxxx>
---

 lib/bitmap.c |   10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

--- a/lib/bitmap.c~bitmap_parselist-move-non-parser-logic-to-helpers-fix
+++ a/lib/bitmap.c
@@ -482,12 +482,12 @@ EXPORT_SYMBOL(bitmap_print_to_pagebuf);
  * 0	   9  12    18			38
  * .........****......****......****......
  *	    ^  ^     ^			 ^
  *      start  off   grlen	       end
  */
 struct region {
 	unsigned int start;
 	unsigned int off;
-	unsigned int grlen;
+	unsigned int group_len;
 	unsigned int end;
 };
 
@@ -499,7 +499,7 @@ static int bitmap_set_region(const struc
 	if (r->end >= nbits)
 		return -ERANGE;
 
-	for (start = r->start; start <= r->end; start += r->grlen)
+	for (start = r->start; start <= r->end; start += r->group_len)
 		bitmap_set(bitmap, start, min(r->end - start + 1, r->off));
 
 	return 0;
@@ -507,7 +507,7 @@ static int bitmap_set_region(const struc
 
 static int bitmap_check_region(const struct region *r)
 {
-	if (r->start > r->end || r->grlen == 0 || r->off > r->grlen)
+	if (r->start > r->end || r->group_len == 0 || r->off > r->group_len)
 		return -EINVAL;
 
 	return 0;
@@ -639,7 +639,7 @@ static int __bitmap_parselist(const char
 
 		r.start = a;
 		r.off = used_size;
-		r.grlen = group_size;
+		r.group_len = group_size;
 		r.end = b;
 
 		ret = bitmap_check_region(&r);
@@ -482,12 +482,12 @@ EXPORT_SYMBOL(bitmap_print_to_pagebuf);
  * .........****......****......****......
  *	    ^  ^     ^			 ^
- *      start  off   grlen	       end
+ *      start  off   group_len	       end
  */
 struct region {
_

Patches currently in -mm which might be from akpm@xxxxxxxxxxxxxxxxxxxx are

mm-utilc-fix-strndup_user-comment.patch
ocfs2-clear-zero-in-unaligned-direct-io-checkpatch-fixes.patch
mm.patch
userfaultfd-sysctl-add-vmunprivileged_userfaultfd-fix.patch
mm-compaction-fix-an-undefined-behaviour-fix.patch
mm-add-probe_user_read-fix.patch
mm-maintain-randomization-of-page-free-lists-checkpatch-fixes.patch
bitmap_parselist-move-non-parser-logic-to-helpers.patch
fs-binfmt_elfc-remove-unneeded-initialization-of-mm-start_stack.patch
convert-struct-pid-count-to-refcount_t-fix.patch
linux-next-rejects.patch
linux-next-git-rejects.patch
scripts-atomic-check-atomicssh-dont-assume-that-scripts-are-executable.patch
mm-rename-ambiguously-named-memorystat-counters-and-functions-fix.patch
kernel-forkc-export-kernel_thread-to-modules.patch
slab-leaks3-default-y.patch




[Index of Archives]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux